----------------------
Sequence/flow diagrams
----------------------

.. image:: images/rucio-get.png
   :scale: 80 %
   :alt: Figure 1
   :align: center

.. image:: images/rucio-register.png
   :scale: 80 %
   :alt: Figure 1
   :align: center      
      
.. image:: images/rucio-put.png
   :scale: 80 %
   :alt: Figure 1
   :align: center      
